Identifies differentially expressed genes between two groups of cells using DEsingle
Usage
DESingleTest(
sub_data,
min_gene_expressed,
min_valid_cells,
contrast = unique(sub_data$compare_group),
parallel = FALSE,
BPPARAM = bpparam()
)Arguments
- sub_data
Count data removed cell_type and selected certain two compare_group
- min_gene_expressed
Genes expressed in minimum number of cells
- min_valid_cells
Minimum number of genes detected in the cell
- contrast
String vector specifying the contrast to be tested against the log2-fold-change threshold
- parallel
If FALSE (default), no parallel computation is used; if TRUE, parallel computation using
BiocParallel, with argumentBPPARAM.- BPPARAM
An optional parameter object passed internally to
bplapplywhenparallel=TRUE. If not specified,bpparam()(default) will be used.