Skip to contents

Identifies differentially expressed genes between two groups of cells using monocle

Usage

MonocleTest(
  sub_data,
  min_gene_expressed,
  min_valid_cells,
  contrast = unique(sub_data$compare_group),
  batch = NULL,
  cores = 4
)

Arguments

sub_data

Count data removed cell_type and selected certain two compare_group

min_gene_expressed

Genes expressed in minimum number of cells

min_valid_cells

Minimum number of genes detected in the cell

contrast

String vector specifying the contrast to be tested against the log2-fold-change threshold

batch

Different batch identifier

cores

The number of cores to be used while testing each gene for differential expression.

Value

A matrix of differentially expressed genes and related statistics.

Details

This test does not support pre-processed genes. To use this method, please install monocle, using the instructions at https://bioconductor.org/packages/release/bioc/html/monocle.html

References

Qiu X, Hill A, Packer J, Lin D, Ma Y, Trapnell C (2017). “Single-cell mRNA quantification and differential analysis with Census.” Nature Methods. https://github.com/cole-trapnell-lab/monocle-release