This function loads the significant interactions as a dataframe, and colors represent different types of cells as a structure. The width of edges represent the strength of the communication. Labels on the edges show exactly how many interactions exist between two types of cells.
Usage
NetView(
data,
col,
label = TRUE,
edge.curved = 0.5,
shape = "circle",
layout = nicely(),
vertex.size = 20,
margin = 0.2,
vertex.label.cex = 1.5,
vertex.label.color = "black",
arrow.width = 1.5,
edge.label.color = "black",
edge.label.cex = 1,
edge.max.width = 10
)Arguments
- data
A dataframe containing ligand-receptor pairs and corresponding cell typesused to do the plotting
- col
Colors used to represent different cell types
- label
Whether or not shows the label of edges (number of connections between different cell types)
- edge.curved
Specifies whether to draw curved edges, or not. This can be a logical or a numeric vector or scalar. First the vector is replicated to have the same length as the number of edges in the graph. Then it is interpreted for each edge separately. A numeric value specifies the curvature of the edge; zero curvature means straight edges, negative values means the edge bends clockwise, positive values the opposite. TRUE means curvature 0.5, FALSE means curvature zero
- shape
The shape of the vertex, currently “circle”, “square”, “csquare”, “rectangle”, “crectangle”, “vrectangle”, “pie” (see vertex.shape.pie), ‘sphere’, and “none” are supported, and only by the plot.igraph command. “none” does not draw the vertices at all, although vertex label are plotted (if given). See shapes for details about vertex shapes and vertex.shape.pie for using pie charts as vertices.
- layout
The layout specification. It must be a call to a layout specification function.
- vertex.size
The size of vertex
- margin
The amount of empty space below, over, at the left and right of the plot, it is a numeric vector of length four. Usually values between 0 and 0.5 are meaningful, but negative values are also possible, that will make the plot zoom in to a part of the graph. If it is shorter than four then it is recycled.
- vertex.label.cex
The label size of vertex
- vertex.label.color
The color of label for vertex
- arrow.width
The width of arrows
- edge.label.color
The color for single arrow
- edge.label.cex
The size of label for arrows
- edge.max.width
The maximum arrow size