This function loads count data as dataframe, ligand, receptor and two interactive cells' names as strings. The plot shows the expression level of ligand and receptor at different time, thus illustrates a dynamic change of a ligand-receptor pairs.
Arguments
- data
A dataframe contains significant ligand-receptor pairs and related information such as expression level/log fold change and cell type
- ligand
String as selected ligand
- receptor
String as selected receptor
- cell_from
The cell type ligand gene belongs to
- cell_to
The cell type receptor gene belongs to
- Time
Different time points showing on the plot