Skip to contents

Identifies differentially expressed genes between two groups of cells using a Wilcoxon Rank Sum test

Usage

WilcoxTest(
  sub_data,
  min_gene_expressed,
  min_valid_cells,
  contrast = unique(sub_data$compare_group),
  datatype = "raw count",
  verbose = FALSE
)

Arguments

sub_data

Count data removed cell_type and selected certain two compare_group

min_gene_expressed

Genes expressed in minimum number of cells

min_valid_cells

Minimum number of genes detected in the cell

contrast

String vector specifying the contrast to be tested against the log2-fold-change threshold

datatype

Type of data. Available options are:

  • 'raw data': Raw count data without any pre-processing

  • 'log count': Normalized and log-transformed data

verbose

Whether show the progress of computing

Value

A matrix of differentially expressed genes and related statistics.