This function loads the count data as a dataframe. It assumes that each line contains gene expression profile of one single cell, and each column contains the one single gene expression profile in different cells. The dataframe should also contain the cell type information with column name 'cell_type'. Group information should also be included as 'compare_group' if users want to call differntial expressed ligand-receptor pairs. Batch information as 'batch' is optional. If included, users may want to use the raw count data for later analysis.